==> mysql-8.0_8.0.45.orig.tar.gz: mysql-8.0.45/sql/psi_memory_resource.h <==
/* Copyright (c) 2023, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef PSI_MEMORY_RESOURCE_H_
#define PSI_MEMORY_RESOURCE_H_

#include "libbinlogevents/include/resource/memory_resource.h"
#include "sql/psi_memory_key.h"

/// Return a PSI-enabled Memory_resource using the given key.
mysqlns::resource::Memory_resource psi_memory_resource(PSI_memory_key key);

#endif  // PSI_MEMORY_RESOURCE_H_

==> mysql-8.4_8.4.6.orig.tar.gz: mysql-8.4.6/sql/psi_memory_resource.h <==
/* Copyright (c) 2023, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef PSI_MEMORY_RESOURCE_H_
#define PSI_MEMORY_RESOURCE_H_

#include "mysql/binlog/event/resource/memory_resource.h"
#include "sql/psi_memory_key.h"

/// Return a PSI-enabled Memory_resource using the given key.
mysql::binlog::event::resource::Memory_resource psi_memory_resource(
    PSI_memory_key key);

#endif  // PSI_MEMORY_RESOURCE_H_
